| getESS | R Documentation |
This function calculates the effective sample size for every dose group via RBesT::ess().
getESS(post_list, method = c("elir", "moment", "morita"), n_digits = 1, ...)
post_list |
A posterior list object, for which the effective sample size for each dose group should be calculated |
method |
A string specifying the method of ESS calculation, see |
n_digits |
An integer for the number of digits the result should be rounded to. |
... |
Optional arguments applicable to specific methods, see |
A vector of the effective sample sizes for each dose group
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.